==> flutter_conscent_plugin-0.3.4.tar.gz: lib/webview_conscent.dart <==
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:io' show Platform;
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'Model/api_mode.dart';
import 'Model/login_challengeget.dart';
import 'constants.dart';
import 'shared_pref.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewAppss(),
    ),
  );
}

class WebViewAppss extends StatefulWidget {
  const WebViewAppss({super.key});

  @override
  State<WebViewAppss> createState() => _WebViewAppStates();
}

class _WebViewAppStates extends State<WebViewAppss> {
  String? loginId;
  // Add from here ...
  bool showContent = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();

  String? subsUrl;
  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  // dynamic dataMain;
  getLoginChallengeId() async {
    subsUrl = await SharedPref().getSubsUrl();
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');

    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {

    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');

    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": clientId,
      "clientContentId": clientContentId,
      "sessionId": sessionId,
    });


    if (response.statusCode == 201) {
      var responseString = response.body;
      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {

    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {

          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();

            String sessionId = await getSessionID(loginId!);
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  @override
  Widget build(BuildContext context) {

    <JavascriptChannel>{_javascriptChannel()};
    String? userAgent = Constants.userAgent;

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl: subsUrl,
              javascriptMode: JavascriptMode.unrestricted,
            userAgent: Platform.isIOS
            ? '${userAgent!} Safari/605.1'
            : userAgent?.replaceAll("; wv", ""),
              onProgress: (int progress) async {

                <JavascriptChannel>{_javascriptChannel()};

              },
              onWebViewCreated: (controller) {

              },
              navigationDelegate: (NavigationRequest request) {

                if (request.url.startsWith('https://xyz.zyz')) {

                  getSessionID(loginId!);


                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  //      .startsWith('https://conscentsss.com/?csc-tierId=${widget.tiersId})')){
                  Navigator.pop(context);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}

==> flutter_conscent_plugin-0.3.6.tar.gz: lib/webview_conscent.dart <==
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import 'dart:io' show Platform;
import 'conscent_initializer.dart';
import 'conscent_methods.dart';
import 'constants.dart';
import 'datamodel/api_mode.dart';
import 'datamodel/login_challengeget.dart';
import 'shared_pref.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewAppss(),
    ),
  );
}

class WebViewAppss extends StatefulWidget {
  const WebViewAppss({super.key});

  @override
  State<WebViewAppss> createState() => _WebViewAppStates();
}

class _WebViewAppStates extends State<WebViewAppss> {
  String? loginId;
  // Add from here ...
  bool showContent = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();

  String? subsUrl;
  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  // dynamic dataMain;
  getLoginChallengeId() async {
    subsUrl = await SharedPref().getSubsUrl();
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    ConscentMethods().onDebugPrint("WebViewAppss loginId.toString() ${loginId.toString()}");
    getSessionID();
    setState(() {});
  }

  Future<String> getSessionID() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');

    var uri = Uri.parse('${ApiMode.BASE_URL}api/v1/login-challenge/$loginId');

    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = loginChallengeget.toString();
      prefs.setString('sessionId', sessionId);
      ConscentMethods().onDebugPrint("WebViewAppss loginChallengeget.toJson() ${loginChallengeget.toJson()} ");
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    ConscentMethods().onDebugPrint("WebViewAppss sessionId = $sessionId");
    var response = await http
        .post(Uri.parse('${ApiMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": clientId,
      "clientContentId": clientContentId,
      "sessionId": sessionId,
    });


    if (response.statusCode == 201) {
      var responseString = response.body;
      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {

    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {

          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();

            String sessionId = await getSessionID();
            submitDatas('${ConscentInitializer.mClientId}',
                '${ConscentInitializer.mContentId}', sessionId);
          }
        });
  }

  @override
  Widget build(BuildContext context) {

    <JavascriptChannel>{_javascriptChannel()};
    String? userAgent = Constants.userAgent;
    print("subsUrl $subsUrl");

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl: subsUrl,
              javascriptMode: JavascriptMode.unrestricted,
            userAgent: Platform.isIOS
            ? '${userAgent!} Safari/605.1'
            : userAgent?.replaceAll("; wv", ""),
              onProgress: (int progress) async {

                <JavascriptChannel>{_javascriptChannel()};

              },
              onWebViewCreated: (controller) {

              },
              navigationDelegate: (NavigationRequest request) {

                if (request.url.startsWith('https://xyz.zyz')) {

                  getSessionID();


                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${ApiMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  //      .startsWith('https://conscentsss.com/?csc-tierId=${widget.tiersId})')){
                  Navigator.pop(context);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}
